@@ -135,6 +135,16 @@ class RenderspecTemplateFunctionTests(unittest.TestCase):
         self.env = Environment()
         renderspec._env_register_filters_and_globals(self.env)
 
+    @data(
+        ("{{ 'http://foo/bar'|basename }}", "bar")
+    )
+    @unpack
+    def test_render_func_basename(self, input, expected):
+        template = self.env.from_string(input)
+        self.assertEqual(
+            template.render(spec_style='suse', epochs={}, requirements={}),
+            expected)
+
     def test_render_func_license_spdx(self):
         template = self.env.from_string(
             "{{ license('Apache-2.0') }}")
@@ -487,6 +497,7 @@ class RenderspecUtilsTests(unittest.TestCase):
     @unpack
     def test__find_archives(self, archives, pypi_name, expected):
         tmpdir = tempfile.mkdtemp(prefix='renderspec-test_')
+        expected = [os.path.join(tmpdir, e) for e in expected]
         try:
             for a in archives:
                 open(os.path.join(tmpdir, a), 'w').close()
@@ -505,7 +516,7 @@ class RenderspecUtilsTests(unittest.TestCase):
             self.assertEqual(
                 renderspec.utils._find_archives([None, tmpdir1, tmpdir2],
                                                 'foo'),
-                ['foo-1.2.3.tar.xz']
+                [os.path.join(tmpdir2, 'foo-1.2.3.tar.xz')]
             )
         finally:
             shutil.rmtree(tmpdir1)
